Check that at least one element is requested
Arguments
- pre
Fetches precipitation (millimetres/month) from server and returns it in the data frame,
TRUE. Defaults toFALSE.- pre_cv
Fetches cv of precipitation (percent) from server and returns it in the data frame,
TRUE. Defaults toFALSE. Note, setting this toTRUEwill always results in pre being set toTRUEand returned as well.- rd0
Fetches wet-days (number days with >0.1 millimetres rain per month) and returns it in the data frame,
TRUE. Defaults toFALSE.- tmp
Fetches temperature (degrees Celsius) and returns it in the data frame,
TRUE. Defaults toFALSE.- dtr
Fetches mean diurnal temperature range (degrees Celsius) and returns it in the data frame,
TRUE. Defaults toFALSE.- reh
Fetches relative humidity and returns it in the data frame,
TRUE. Defaults toFALSE.- tmn
Calculates minimum temperature values (degrees Celsius) and returns it in the data frame. Defaults to
FALSE.- tmx
Boolean. Calculates maximum temperature (degrees Celsius) and returns it in the data frame,
TRUE. Defaults toFALSE.- sunp
Fetches sunshine, percent of maximum possible (percent of day length), and returns it in the data frame,
TRUE. Defaults toFALSE.- frs
Boolean. Fetches ground-frost records (number of days with ground-frost per month) and returns it in data frame,
TRUE. Defaults toFALSE.- wnd
Fetches 10m wind speed (metres/second) and returns it in the data frame,
TRUE. Defaults toFALSE.- elv
Fetches elevation (converted to metres) and returns it in the data frame,
TRUE. Defaults toFALSE.